#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 aws
version:              0.22
visibility:           public
id:                   aws-0.22-H7NFLoJwiCXFjiIVxafjrQ
key:                  aws-0.22-H7NFLoJwiCXFjiIVxafjrQ
license:              BSD-3-Clause
copyright:            See contributors list in README and LICENSE file
maintainer:           aristidb@gmail.com
author:               Aristid Breitkreuz, contributors see README
homepage:             http://github.com/aristidb/aws
synopsis:             Amazon Web Services (AWS) for Haskell
description:
    Bindings for Amazon Web Services (AWS), with the aim of supporting all AWS services. To see a high level overview of the library, see the README at <https://github.com/aristidb/aws/blob/master/README.md>.

category:             Network, Web, AWS, Cloud, Distributed Computing
abi:                  2fca83d9fcfc7651d7699aaa54102ff5
exposed:              True
exposed-modules:
    Aws Aws.Aws Aws.Core Aws.DynamoDb Aws.DynamoDb.Commands
    Aws.DynamoDb.Commands.BatchGetItem
    Aws.DynamoDb.Commands.BatchWriteItem
    Aws.DynamoDb.Commands.DeleteItem Aws.DynamoDb.Commands.GetItem
    Aws.DynamoDb.Commands.PutItem Aws.DynamoDb.Commands.Query
    Aws.DynamoDb.Commands.Scan Aws.DynamoDb.Commands.Table
    Aws.DynamoDb.Commands.UpdateItem Aws.DynamoDb.Core
    Aws.Ec2.InstanceMetadata Aws.Iam Aws.Iam.Commands
    Aws.Iam.Commands.AddUserToGroup Aws.Iam.Commands.CreateAccessKey
    Aws.Iam.Commands.CreateGroup Aws.Iam.Commands.CreateUser
    Aws.Iam.Commands.DeleteAccessKey Aws.Iam.Commands.DeleteGroup
    Aws.Iam.Commands.DeleteGroupPolicy Aws.Iam.Commands.DeleteUser
    Aws.Iam.Commands.DeleteUserPolicy Aws.Iam.Commands.GetGroupPolicy
    Aws.Iam.Commands.GetUser Aws.Iam.Commands.GetUserPolicy
    Aws.Iam.Commands.ListAccessKeys Aws.Iam.Commands.ListGroupPolicies
    Aws.Iam.Commands.ListGroups Aws.Iam.Commands.ListMfaDevices
    Aws.Iam.Commands.ListUserPolicies Aws.Iam.Commands.ListUsers
    Aws.Iam.Commands.PutGroupPolicy Aws.Iam.Commands.PutUserPolicy
    Aws.Iam.Commands.RemoveUserFromGroup
    Aws.Iam.Commands.UpdateAccessKey Aws.Iam.Commands.UpdateGroup
    Aws.Iam.Commands.UpdateUser Aws.Iam.Core Aws.Iam.Internal
    Aws.Network Aws.S3 Aws.S3.Commands Aws.S3.Commands.CopyObject
    Aws.S3.Commands.DeleteBucket Aws.S3.Commands.DeleteObject
    Aws.S3.Commands.DeleteObjectVersion Aws.S3.Commands.DeleteObjects
    Aws.S3.Commands.GetBucket Aws.S3.Commands.GetBucketLocation
    Aws.S3.Commands.GetBucketObjectVersions Aws.S3.Commands.GetObject
    Aws.S3.Commands.GetService Aws.S3.Commands.HeadObject
    Aws.S3.Commands.Multipart Aws.S3.Commands.PutBucket
    Aws.S3.Commands.PutBucketVersioning Aws.S3.Commands.PutObject
    Aws.S3.Core Aws.Ses Aws.Ses.Commands
    Aws.Ses.Commands.DeleteIdentity
    Aws.Ses.Commands.GetIdentityDkimAttributes
    Aws.Ses.Commands.GetIdentityNotificationAttributes
    Aws.Ses.Commands.GetIdentityVerificationAttributes
    Aws.Ses.Commands.ListIdentities Aws.Ses.Commands.SendRawEmail
    Aws.Ses.Commands.SetIdentityDkimEnabled
    Aws.Ses.Commands.SetIdentityFeedbackForwardingEnabled
    Aws.Ses.Commands.SetIdentityNotificationTopic
    Aws.Ses.Commands.VerifyDomainDkim
    Aws.Ses.Commands.VerifyDomainIdentity
    Aws.Ses.Commands.VerifyEmailIdentity Aws.Ses.Core Aws.SimpleDb
    Aws.SimpleDb.Commands Aws.SimpleDb.Commands.Attributes
    Aws.SimpleDb.Commands.Domain Aws.SimpleDb.Commands.Select
    Aws.SimpleDb.Core Aws.Sqs Aws.Sqs.Commands Aws.Sqs.Commands.Message
    Aws.Sqs.Commands.Permission Aws.Sqs.Commands.Queue
    Aws.Sqs.Commands.QueueAttributes Aws.Sqs.Core

import-dirs:          /usr/lib/ghc-8.10.2/site-local/aws-0.22
library-dirs:         /usr/lib/ghc-8.10.2/site-local/aws-0.22
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/i386-linux-ghc-8.10.2/aws-0.22
hs-libraries:         HSaws-0.22-H7NFLoJwiCXFjiIVxafjrQ
depends:
    aeson-1.5.4.1-1IeGMr9U117LwJYrLRVKTY
    attoparsec-0.13.2.4-AOCP0w3yjps1ekkc06TeAr base-4.14.1.0
    base16-bytestring-0.1.1.7-7MnoTKrQfBC3WeMx0LqUK0
    base64-bytestring-1.2.0.1-DXjYz6nIlWlBo5PzDNkE0m
    blaze-builder-0.4.1.0-G4KXEZbDrFS6c5MmayHGI7
    byteable-0.1.1-FeSdIMqUIcwI3U3IhpOBJ3 bytestring-0.10.10.0
    case-insensitive-1.2.1.0-IEhoEA2Y3hEInpr65wUbwd
    cereal-0.5.8.1-56yg04wGStN22upOSM9put
    conduit-1.3.4-4jvOBOzxV1hIVvrhitNicH
    conduit-extra-1.3.5-HfFATvBEagDKm7nPa1b9L3 containers-0.6.2.1
    cryptonite-0.27-HpkQ9Stao3P6Ep1pdHbpFR
    data-default-0.7.1.1-7HoN0t9OYRgIKYZBJZGYs directory-1.3.6.0
    exceptions-0.10.4 filepath-1.4.2.1
    http-client-tls-0.3.5.3-JmjUjXMBBQrFxLND03KIyi
    http-conduit-2.3.7.3-1gPhGmLd46pAQjucY9rkwt
    http-types-0.12.3-DFZTOe1tP827vA146GCQqh
    lifted-base-0.2.3.12-FNR3Y0kP2ZQ6UZTjrjVcBa
    memory-0.15.0-359cYXe7lRF64CAN0G53fp
    monad-control-1.0.2.3-HDNIrqERwQpLu9U0yfDaUG mtl-2.2.2
    network-3.1.2.0-4HePmu7VkBtBCaHVjBpjhx
    network-bsd-2.8.1.0-E2dgjqwSYikA1Ra5jxnBhC
    old-locale-1.0.0.7-LpTuchyagHAP7STZdm71P
    resourcet-1.2.4.2-IBltYvRLbCe9QRRPgabVbi
    safe-0.3.19-AfrHSVViU1189qUhjBUb5b
    scientific-0.3.6.2-LcQZB4QBvhUBZy7r760l30
    tagged-0.8.6-6ynGuqiqWewDmeFAuVgKQe text-1.2.3.2 time-1.9.3
    transformers-0.5.6.2
    unordered-containers-0.2.13.0-7BSbisgDeQuHhhzTcs4ukq
    utf8-string-1.0.1.1-G1tzxDqsWge3erFqc4Oe2R
    vector-0.12.1.2-IO5RJnkQnAxDAG50LdixTd
    xml-conduit-1.9.0.0-2JvONuwI3yc32PhHvznlaI

haddock-interfaces:   /usr/share/doc/haskell-aws/html/aws.haddock
haddock-html:         /usr/share/doc/haskell-aws/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

